@@ -1,7 +1,7 @@
 package File::Copy::Undoable;
 
-our $DATE = '2015-08-29'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -162,7 +162,7 @@ File::Copy::Undoable - Copy file/directory using rsync, with undo support
 
 =head1 VERSION
 
-This document describes version 0.08 of File::Copy::Undoable (from Perl distribution File-Copy-Undoable), released on 2015-08-29.
+This document describes version 0.09 of File::Copy::Undoable (from Perl distribution File-Copy-Undoable), released on 2015-09-03.
 
 =head1 FAQ
 
@@ -184,9 +184,8 @@ L<Rinci::Transaction>
 
 =head2 cp(%args) -> [status, msg, result, meta]
 
-{en_US Copy file/directory using rsync, with undo support}.
+Copy file/directory using rsync, with undo support.
 
-{en_US 
 On do, will copy C<source> to C<target> (which must not exist beforehand). On
 undo, will trash C<target>.
 
@@ -196,7 +195,6 @@ checked; only existence.
 Fixable state: C<source> exists and C<target> doesn't exist.
 
 Unfixable state: C<source> does not exist.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -207,45 +205,37 @@ Arguments ('*' denotes required arguments):
 
 =item * B<rsync_opts> => I<array[str]> (default: ["-a"])
 
-{en_US Rsync options}.
+Rsync options.
 
-{en_US 
 By default, C<-a> is used. You can add, for example, C<--delete> or other rsync
 options.
-}
 
 =item * B<source>* => I<str>
 
 =item * B<target>* => I<str>
 
-{en_US Target location}.
+Target location.
 
-{en_US 
 Note that to avoid ambiguity, you must specify full location instead of just
 directory name. For example: cp(source=>'/dir', target=>'/a') will copy /dir to
 /a and cp(source=>'/dir', target=>'/a/dir') will copy /dir to /a/dir.
-}
 
 =item * B<target_group> => I<str>
 
-{en_US Set group of target}.
+Set group of target.
 
-{en_US 
 See C<target_owner>.
-}
 
 =item * B<target_owner> => I<str>
 
-{en_US Set ownership of target}.
+Set ownership of target.
 
-{en_US 
 If set, will do a C<chmod -Rh> on the target after rsync to set ownership. This
 usually requires super-user privileges. An example of this is copying files on
 behalf of user from a source that is inaccessible by the user (e.g. a system
 backup location). Or, setting up user's home directory when creating a user.
 
 Will do nothing if not running as super-user.
-}
 
 =back
 
